#
# spec file for package ghc-brick
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name brick
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.67
Release:        bp155.2.14
Summary:        A declarative terminal user interface library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-config-ini-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-contravariant-devel
BuildRequires:  ghc-data-clist-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-dlist-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-microlens-mtl-devel
BuildRequires:  ghc-microlens-th-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-zipper-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vty-devel
BuildRequires:  ghc-word-wrap-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
%endif

%description
Write terminal user interfaces (TUIs) painlessly with 'brick'! You write an
event handler and a drawing function and the library does the rest.

> module Main where > > import Brick > > ui :: Widget () > ui = str "Hello,
world!" > > main :: IO () > main = simpleMain ui

To get started, see:

* <https://github.com/jtdaugherty/brick/blob/master/README.md The README>

* The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick
user guide>

* The demonstration programs in the 'programs' directory

This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md docs

%changelog
* Mon Jan 31 2022 Peter Simons <psimons@suse.com>
- Update brick to version 0.67.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/brick-0.67/src/CHANGELOG.md
* Sat Nov 20 2021 psimons@suse.com
- Update brick to version 0.65.
  0.65
  - ---
  New features and API changes:
  * Viewports got support for built-in scroll bar rendering. This
    includes additions of types and functions to manage the feature
    behavior. These changes enable viewports to automatically get
    scroll bars drawn next to them (on any side) with customizable
    attributes and drawings. As part of this change, a new demo program,
    `ViewportScrollbarsDemo.hs`, was added to show off these new
    features. Here are the new types and functions that got added (mostly
    to `Brick.Widgets.Core`):
  * `withVScrollBars` - enable display of vertical scroll bars
  * `withHScrollBars` - enable display of horizontal scroll bars
  * `withClickableVScrollBars` - enable mouse click reporting on
    vertical scroll bar elements
  * `withClickableHScrollBars` - enable mouse click reporting on
    horizontal scroll bar elements
  * `ClickableScrollbarElement` - the type of elements of a scroll bar
    that can be clicked on and provided to the application
  * `withVScrollBarHandles` - enable vertical scroll bar handle drawing
  * `withHScrollBarHandles` - enable horizontal scroll bar handle
    drawing
  * `withVScrollBarRenderer` - customize the renderer used for vertical
    scroll bars
  * `withHScrollBarRenderer` - customize the renderer used for
    horizontal scroll bars
  * `ScrollbarRenderer(..)` - the type of scroll bar renderer
    implementations
  * `verticalScrollbarRenderer` - the default renderer for vertical
    scrollbars, customizable with `withVScrollBarRenderer`
  * `horizontalScrollbarRenderer` - the default renderer for horizontal
    scrollbars, customizable with `withHScrollBarRenderer`
  * `scrollbarAttr` - the base attribute of scroll bars
  * `scrollbarTroughAttr` - the attribute of scroll bar troughs
  * `scrollbarHandleAttr` - the attribute of scroll bar handles
  Package changes:
  * Raised `base` bounds to allow building with GHC 9.2.1 (thanks Mario
    Lang)
  * Stopped supporting GHC 7.10.
* Mon Nov  1 2021 psimons@suse.com
- Update brick to version 0.64.2.
  0.64.2
  - -----
  Bug fixes:
  * `Brick.Themes.saveTheme` now correctly saves background colors (#338)
  * `Brick.Widgets.List.listMoveToEnd` now uses the correct destination
    index (#337)
* Mon Sep 20 2021 psimons@suse.com
- Update brick to version 0.64.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/brick-0.64.1/src/CHANGELOG.md
* Wed Aug 25 2021 psimons@suse.com
- Update brick to version 0.64.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/brick-0.64/src/CHANGELOG.md
* Fri Apr 30 2021 psimons@suse.com
- Update brick to version 0.62.
  0.62
  - ---
  API changes:
  * `Brick.Widgets.Core` got new functions
    `crop{Left,Right,Bottom,Top}To`. Unlike the `crop...By` functions,
    which crop on the specified side by a particular amount, these
    `crop...To` functions crop on the specified side and take a desired
    overall width of the final result and use that to determine how much
    to crop. A widget `x` of width `w` could thus be cropped equivalently
    with `cropLeftBy a x` and `cropLeftTo (w - a) x`.
  Other changes:
  * Added `programs/CroppingDemo.hs` to demonstrate the new (and
    preexisting) cropping functions.
* Fri Apr  9 2021 psimons@suse.com
- Update brick to version 0.61.
  0.61
  - ---
  API changes:
  * Brick.Forms got `editShowableFieldWithValidate`, a generalization
    of `editShowableField` that allows the caller to specify an
    additional validation function (thanks Ben Selfridge)
* Tue Apr  6 2021 psimons@suse.com
- Update brick to version 0.60.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Feb  8 2021 psimons@suse.com
- Update brick to version 0.60.2.
  0.60.2
  - -----
  Bug fixes:
  * Widgets reported as `clickable` are now reported as clickable even
    when their renderings are cached with `cached` (#307; thanks Hari
    Menon)
* Wed Feb  3 2021 psimons@suse.com
- Update brick to version 0.60.1.
  0.60.1
  - -----
  Bug fixes:
  * `table []` no longer raises `TEUnequalRowSizes`.
  0.60
  - ---
  New features:
  * Added `Brick.Widgets.Table` to support drawing basic tables. See
    `programs/TableDemo.hs` for a demonstration (`cabal new-run -f demos
    brick-table-demo`).
* Fri Jan 29 2021 psimons@suse.com
- Update brick to version 0.59.
  0.59
  - ---
  API changes:
  * `Brick.Widgets.List` got `listMoveToBeginning` and `listMoveToEnd`
    functions
  * `Extent`: removed the unused `extentOffset` field
  Bug fixes:
  * Fixed a crash in the border rewriting code that attempted to rewrite
    empty images (#305) (thanks @dmwit)
* Tue Dec 29 2020 psimons@suse.com
- Update brick to version 0.58.1.
  0.58.1
  - -----
  Bug fixes:
  * Removed a defunct failing test from the List test suite
* Tue Dec 22 2020 psimons@suse.com
- Update brick to version 0.58.
  0.58
  - ---
  Package changes:
  * Updated dependency constraints to build on GHC 9.0.1 (thanks Ondřej
    Súkup)
  API changes:
  * The FileBrowser module now exports individual functions for
    each of the events that it handles. This allows end users to
    trigger the behaviors directly rather than relying on the built-in
    `handleFileBrowserEvent` function. The documentation has been updated
    to indicate which functions are triggered by each key event. (Thanks
    David B. Lamkins)
  Other changes:
  * The `List` module's `listFindBy` function now attempts to find a
    match anywhere in the list rather than just somewhere between the
    cursor and the end of the list.
  * The `FileBrowser` now positions a cursor at the beginning of the
    selected entry when the file browser is focused. (thanks Mario Lang)
  * The user guide's viewport visibility example got an important
    syntactic fix. (thanks Mario Lang)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Nov 15 2020 psimons@suse.com
- Update brick to version 0.57.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Nov 15 2020 psimons@suse.com
- Update brick to version 0.57.1.
  0.57.1
  - -----
  Bug fixes:
  * Fixed a small space leak in the main rendering loop (#260)
  * Get `TailDemo` building on more versions of GHC
* Tue Oct  6 2020 psimons@suse.com
- Update brick to version 0.57.
  0.57
  - ---
  Package changes:
  * Raised lower bound on `vty` to 5.31 to get the new `strikethrough`
    style.
  New features:
  * Added support for the `strikethrough` style in Brick theme
    customization files.
* Sun Sep 27 2020 psimons@suse.com
- Update brick to version 0.56.
  0.56
  - ---
  Package changes:
  * Increased upper bound for `base` to support GHC 8.10.2 (thanks Ryan
    Scott)
  API changes:
  * Added `Brick.Forms.updateFormState` to update the state contained
    within (and managed by) a Form. This function takes care of the
    details of updating the form fields themselves to be consistent with
    the change in underlying state.
  * Added the overall window width (`windowWidth`) and height
    (`windowHeight`) to `Context`, the rendering context type (thanks Tom
    McLaughlin)
  Other changes:
  * Added `brick-tail-demo`, a demonstration program for writing a
    `tail`-style output-following interface.
  * Updated `Brick.Widgets.ProgressBar` so that it handles near-endpoint
    cases more naturally (fixes #281)
* Mon Aug 31 2020 psimons@suse.com
- Update brick to version 0.55 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to accept latest base version.
* Fri Jul 10 2020 psimons@suse.com
- Update brick to version 0.55.
  0.55
  - ---
  Package changes:
  * Increased lower bound on `vty` dependency to 5.29.
  Bug fixes:
  * `customMain` now restores the initial terminal input state on
    shutdown. This means that changes to the input state flags in the last
    `suspendAndResume` before program exit are no longer propagated to the
    end user's terminal environment (which could lead to broken or garbled
    terminal I/O).
* Tue Jun  9 2020 psimons@suse.com
- Add brick at version 0.54.
